@@ -1,9 +1,3 @@
-/* eslint-disable
-  global-require,
-  no-param-reassign,
-  prefer-destructuring,
-  import/no-dynamic-require,
-*/
 import { getOptions } from 'loader-utils';
 import validateOptions from 'schema-utils';
 import mime from 'mime';
@@ -16,10 +10,14 @@ function shouldTransform(limit, size) {
     return limit;
   }
 
-  if (typeof limit === 'number' || typeof limit === 'string') {
+  if (typeof limit === 'string') {
     return size <= parseInt(limit, 10);
   }
 
+  if (typeof limit === 'number') {
+    return size <= limit;
+  }
+
   return true;
 }
 
@@ -27,19 +25,27 @@ export default function loader(src) {
   // Loader Options
   const options = getOptions(this) || {};
 
-  validateOptions(schema, options, 'URL Loader');
+  validateOptions(schema, options, {
+    name: 'URL Loader',
+    baseDataPath: 'options',
+  });
 
   // No limit or within the specified limit
   if (shouldTransform(options.limit, src.length)) {
     const file = this.resourcePath;
-    // Get MIME type
     const mimetype = options.mimetype || mime.getType(file);
 
     if (typeof src === 'string') {
+      // eslint-disable-next-line no-param-reassign
       src = Buffer.from(src);
     }
 
-    return `module.exports = ${JSON.stringify(
+    const esModule =
+      typeof options.esModule !== 'undefined' ? options.esModule : true;
+
+    return `${
+      esModule ? 'export default' : 'module.exports ='
+    } ${JSON.stringify(
       `data:${mimetype || ''};base64,${src.toString('base64')}`
     )}`;
   }
@@ -51,6 +57,7 @@ export default function loader(src) {
   } = normalizeFallback(options.fallback, options);
 
   // Require the fallback.
+  // eslint-disable-next-line global-require, import/no-dynamic-require
   const fallback = require(fallbackLoader);
 
   // Call the fallback, passing a copy of the loader context. The copy has the query replaced. This way, the fallback
